@@ -328,6 +328,7 @@ testIInterface (test_TestFactory   factory,
 	CORBA_char       *type_id;
 	ORBit_IInterface *iinterface;
 	CORBA_sequence_CORBA_TypeCode *tcs;
+	CORBA_TypeCode tc;
 
 	d_print ("Testing IInterface code...\n");
 	objref = test_TestFactory_getStructServer (factory, ev);
@@ -390,6 +391,16 @@ testIInterface (test_TestFactory   factory,
 	g_assert (find_tc (tcs, "IDL:orbit/test/EnumUnion/Colour:1.0"));
 	g_assert (find_tc (tcs, "IDL:orbit/test/ArrayUnion:1.0"));
 	CORBA_free (tcs);
+
+	/* test subnames for unions correctly handle multiple case
+	 * labels pointing at the same sub type. */
+	tc = TC_test_FixedLengthUnion;
+	g_assert(tc->sub_parts == 5);
+	g_assert(!strcmp(tc->subnames[0], "x"));
+	g_assert(!strcmp(tc->subnames[1], "y"));
+	g_assert(!strcmp(tc->subnames[2], "z"));
+	g_assert(!strcmp(tc->subnames[3], "z"));
+	g_assert(!strcmp(tc->subnames[4], "v"));
 }
 
 static void
@@ -672,7 +683,6 @@ testFixedLengthUnion (test_TestFactory   factory,
   g_assert (retn._d == 'd');
   g_assert (retn._u.z == FALSE);
 
-
   CORBA_Object_release (objref, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 }
@@ -1458,9 +1468,13 @@ test_BasicServer_opStringA_cb (CORBA_Object          object,
 	CORBA_char  *inout_str = NULL, *out_str, *ret_str;
 	CORBA_char **out_str_shim = &out_str;
 
-	gpointer args[] = { NULL, &inout_str, &out_str_shim };
+	gpointer args[3];
 	gpointer ret    = &ret_str;
 
+	args[0] = NULL;
+	args[1] = &inout_str;
+	args[2] = &out_str_shim;
+
 	/* Not a broken connection */
 	g_assert (ev->_major == CORBA_NO_EXCEPTION);
 
@@ -1484,9 +1498,13 @@ test_BasicServer_opStringA (CORBA_Object       obj,
 			    const CORBA_char  *inout_str, 
 			    CORBA_Environment *ev)
 {
-	gpointer args[] = { &in_str, &inout_str, NULL };
+	gpointer args[3];
 	ORBit_IMethod *m_data;
 
+	args[0] = &in_str;
+	args[1] = &inout_str;
+	args[2] = NULL;
+
 	m_data = &test_BasicServer__iinterface.methods._buffer[3];
 	/* if this failed, we re-ordered the IDL ... */
 	g_assert (!strcmp (m_data->name, "opString"));
@@ -1596,6 +1614,20 @@ testPingPong (test_TestFactory   factory,
 	g_assert (!CORBA_Object_is_equivalent (
 		CORBA_OBJECT_NIL, l_objref, ev));
 
+#if 0
+	/* Test blocking bits - try to blow the remote guy's stack */
+	if (!in_proc) {
+		int i;
+
+		d_print ("Testing client limiting of stack smash on remote server\n");
+		for (i = 0; i < 10000; i++) {
+			test_PingPongServer_opOneWayCallback (r_objref, l_objref, ev);
+			g_assert (ev->_major == CORBA_NO_EXCEPTION);
+		}
+		test_PingPongServer_opRoundTrip (r_objref, ev);
+	}
+#endif
+
 	if (!in_proc) {
 		int i;
 		ORBitConnection *cnx = ORBit_small_get_connection (r_objref);
@@ -1609,7 +1641,7 @@ testPingPong (test_TestFactory   factory,
 			"the write has failed & that the connection is "
 			"now saturated ";
 		char *str;
-		gboolean broken;
+		gboolean broken = FALSE;
 
 		g_assert (cnx != NULL);
 		ORBit_connection_set_max_buffer (cnx, 10000);
@@ -1865,6 +1897,12 @@ main (int argc, char *argv [])
 	/* Tell linc we want a threaded ORB */
 	linc_set_threaded (TRUE);
 
+/* FIXME - make this work nicely sometime.
+	global_orb = CORBA_ORB_init (&argc, argv, "", &ev);
+	g_assert (ev._major == CORBA_NO_EXCEPTION);
+	CORBA_Object_release (global_orb, &ev);
+	g_assert (ev._major == CORBA_NO_EXCEPTION);
+*/
 	global_orb = CORBA_ORB_init (&argc, argv, "", &ev);
 	g_assert (ev._major == CORBA_NO_EXCEPTION);
 
@@ -1909,7 +1947,7 @@ main (int argc, char *argv [])
 		g_assert (ev._major == CORBA_NO_EXCEPTION);
 
 		if (CORBA_Object_non_existent (factory, &ev))
-			g_error  ("Start the server before running the client");
+			g_error  ("Can't contact the server");
 		g_assert (ev._major == CORBA_NO_EXCEPTION);
 	}
 	run_tests (factory, &ev);
